@@ -12,17 +12,22 @@ def main():
     readme_path = next((path for path in github_path.iterdir() if path.stem.startswith("TEMPLATE_README")), None)
 
     if readme_path is None:
-        print(f"Logging files: {list(Path(os.getenv('GITHUB_WORKSPACE')).resolve().iterdir())}")
-        raise Exception(f"Error: A README template must be present in the {github_path} directory")
+        raise Exception("Error: A README template must be present in the base of the .github directory")
 
     with open(readme_path, encoding="utf-8") as readme_template:
         readme_template = readme_template.read()
 
-    with open(workplace_path / "views_chart.txt", encoding="utf-8") as views_chart:
-        views_chart = views_chart.read()
+    if (workplace_path / "views_chart.txt").exists():
+        with open(workplace_path / "views_chart.txt", encoding="utf-8") as views_chart:
+            views_chart = views_chart.read()
+    else:
+        views_chart = ""
 
-    with open(workplace_path / "clones_chart.txt", encoding="utf-8") as clones_chart:
-        clones_chart = clones_chart.read()
+    if (workplace_path / "clones_chart.txt").exists():
+        with open(workplace_path / "clones_chart.txt", encoding="utf-8") as clones_chart:
+            clones_chart = clones_chart.read()
+    else:
+        clones_chart = ""
 
     readme = readme_template.format(VIEWS_CHART=views_chart, CLONES_CHART=clones_chart)
 
